@@ -11,7 +11,7 @@ import sys
 import time
 
 
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 
 
 class CursesContext:
@@ -43,7 +43,7 @@ class PlotWidget:
     STATS_FLOAT_FORMAT = r'{:6.2f}'
     STATS_INT_FORMAT = r'{:6d}'
 
-    def __init__(self, stdscr, color, symbol, border):
+    def __init__(self, stdscr, color, symbol, border, fixed_min, fixed_max):
         self.stdscr = stdscr
         self._queue = collections.deque(maxlen=1000)
         self.color = curses.color_pair(color)
@@ -51,10 +51,13 @@ class PlotWidget:
         self.border = border
         self.min_value = None
         self.max_value = None
-        self.is_natural = None
+        self.fixed_min = fixed_min
+        self.fixed_max = fixed_max
+        self.is_natural = True
 
     def append(self, value):
-        self.is_natural = value % 1 == 0.0
+        if self.is_natural:
+            self.is_natural = value % 1 == 0.0
         if self.min_value is None:
             self.min_value = self.max_value = value
         else:
@@ -77,19 +80,23 @@ class PlotWidget:
         else:
             min_value, max_value = self.min_value, self.max_value
 
+        self.add_plot(values, height, min_value, max_value)
+        self.add_stats(width, height, min_value, current_value, max_value)
+        self.stdscr.refresh()
+
+    def add_plot(self, values, height, min_value, max_value):
+        if self.fixed_min is not None:
+            min_value = self.fixed_min
+        if self.fixed_max is not None:
+            max_value = self.fixed_max
+
         if max_value == min_value:
             # draw middle value
             height_k = height
-            values[0] += 0.5
+            values = [0.5] * len(values)
         else:
             height_k = height / (max_value - min_value)
 
-        self.add_plot(values, height, height_k, min_value)
-        self.add_stats(width, height, min_value, current_value, max_value)
-
-        self.stdscr.refresh()
-
-    def add_plot(self, values, height, height_k, min_value):
         for x, value in enumerate(values):
             value = int((value - min_value) * height_k)
             value = height - value
@@ -147,6 +154,8 @@ def parse_args():
     parser.add_argument('--color', default=2, type=int)
     parser.add_argument('--symbol', default='█', type=perfect_symbol)
     parser.add_argument('--border', default='all', choices=['all', 'window'])
+    parser.add_argument('--min', type=float)
+    parser.add_argument('--max', type=float)
     return parser.parse_args()
 
 
@@ -158,7 +167,12 @@ def main(args):
 
     with CursesContext() as curses_context:
         plot = PlotWidget(
-            curses_context.stdscr, args.color, args.symbol, args.border,
+            curses_context.stdscr,
+            args.color,
+            args.symbol,
+            args.border,
+            args.min,
+            args.max,
         )
 
         while True:
